@@ -113,7 +113,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  http://redmine.open-bio.org/projects/bioperl/
 
 =head1 AUTHOR - Stephen Montgomery
 
@@ -491,7 +491,8 @@ sub _runlagan {
 
     if (($self->silent ||  $self->quiet) &&
         ($^O !~ /os2|dos|MSWin32|amigaos/)) {
-      $command_string .= ' > /dev/null 2> /dev/null';
+      my $null = ($^O =~ m/mswin/i) ? 'NUL' : '/dev/null';
+      $command_string .= " > $null 2> $null";
 
     }
     
