@@ -185,7 +185,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  http://redmine.open-bio.org/projects/bioperl/
 
 =head1 AUTHOR - Shawn Hoon 
 
@@ -423,7 +423,8 @@ sub _run {
     chdir($self->tempdir);
 	#open a pipe to run neighbor to bypass interactive menus
     if ($self->quiet() || $self->verbose() < 0) {
-	open(NEIGHBOR,"|".$self->executable.">/dev/null");
+	my $null = ($^O =~ m/mswin/i) ? 'NUL' : '/dev/null';
+	open(NEIGHBOR,"|".$self->executable.">$null");
     }
     else {
 	open(NEIGHBOR,"|".$self->executable);
