@@ -421,7 +421,8 @@ sub _run {
     chdir($self->tempdir);
     #open a pipe to run protdist to bypass interactive menus
     if ($self->quiet() || $self->verbose() < 0) {
-	open(PROTDIST,"|".$self->executable .">/dev/null");
+	my $null = ($^O =~ m/mswin/i) ? 'NUL' : '/dev/null';
+	open(PROTDIST,"|".$self->executable .">$null");
     }
     else {
 	open(PROTDIST,"|".$self->executable);
